;; 
;; /etc/emacs/site-start.d/50dpkg-dev.el
;;
;; Copyright (C) 1997, Klee Dienes <klee@mit.edu>
;; I hereby release this progam into the public domain.

(autoload 'debian-changelog-mode "/usr/share/emacs/site-lisp/debian-changelog-mode.el"
        "Major mode for editing Debian-style change logs." t)
